@@ -96,8 +96,7 @@ def euler(f, ics, step_size, x1):
 
             # New values of dy/dx, y, x
             y_new = y_vals[-1] + step_size * y_deriv_vals[-1]
-            y_deriv_new = y_deriv_vals[-1] + step_size * \
-                f(y_deriv_vals[-1], y_vals[-1], x_vals[-1])
+            y_deriv_new = y_deriv_vals[-1] + step_size * f(y_deriv_vals[-1], y_vals[-1], x_vals[-1])
             x_new = x_vals[-1] + step_size
 
             # New values get appended to solution vectots
